@@ -6,6 +6,13 @@ import dataclasses_json
 from ..json import DataJsonFormat, package_json_format
 
 
+@dataclasses_json.dataclass_json(letter_case=dataclasses_json.LetterCase.CAMEL)
+@dataclasses.dataclass()
+class ManifestSequence:
+    name: str
+    schema: str
+
+
 @dataclasses_json.dataclass_json(letter_case=dataclasses_json.LetterCase.CAMEL)
 @dataclasses.dataclass()
 class ManifestTableSegmentId:
@@ -36,6 +43,7 @@ class ManifestTable:
 @dataclasses_json.dataclass_json(letter_case=dataclasses_json.LetterCase.CAMEL)
 @dataclasses.dataclass()
 class Manifest:
+    sequences: typing.Dict[str, ManifestSequence]
     tables: typing.Dict[str, ManifestTable]
 
 
